Stan Math Library: stan/math/prim/mat/meta/is_constant_struct.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_constant_struct.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_IS_CONSTANT_STRUCT_HPP
2 #define STAN_MATH_PRIM_MAT_META_IS_CONSTANT_STRUCT_HPP
3
4 #include <stan/math/prim/arr/meta/is_constant_struct.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/scal/meta/is_constant.hpp>
7
8
9 namespace stan {
10
11 template <typename T, int R, int C>
12 struct is_constant_struct<Eigen::Matrix<T, R, C> > {
13 enum { value = is_constant_struct<T>::value };
14 };
15
16 template <typename T>
17 struct is_constant_struct<Eigen::Block<T> > {
18 enum { value = is_constant_struct<T>::value };
19 };
20
21 }
22 #endif
23
is_constant_struct.hpp
stan::is_constant_struct::value
Definition: is_constant_struct.hpp:14
stan
Definition: log_sum_exp.hpp:8
Eigen
(Expert) Numerical traits for algorithmic differentiation variables.
Definition: Eigen_NumTraits.hpp:8
stan::is_constant_struct
Metaprogram to determine if a type has a base scalar type that can be assigned to type double...
Definition: is_constant_struct.hpp:13
Eigen.hpp
is_constant.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.